stream_results_to_file

Function stream_results_to_file 

async fn stream_results_to_file(
    stream: Streaming<ReplyBatch>,
    m_def: &ScheduleMeasurement,
    args: MeasurementExecutionArgs<'_>,
    m_time: Option<f32>,
) -> Result<(), Box<dyn Error>>
Consume the orchestrator’s result stream and write the replies to file.

Shared by hitlist-based and live measurements. A progress bar is shown only when an estimated measurement duration is provided (live measurements are open-ended).